agde::sync

Struct Request

source
pub struct Request { /* private fields */ }
Request to sync selected resources.

Obtained from RequestBuilder, which you get from crate::Manager::apply_hash_check_reply. This is the last request of the series of assuring data is the same across all piers.